const chalk = require('chalk')
const ksuid = require('ksuid')
const path = require('path')
const fs = require('fs-extra')

const docker = require('./utils/docker')
const output = require('./utils/output')
const { getConfig } = require('./utils/config')

module.exports = async function build(input = {}) {
  const config = await getConfig(input)
  const pathText = output.param(config.pathDir)
  const clusterName = output.param(config.cluster)
  const rbacUser = output.param(config.user)

  const doneWithBuild = output.wait('Building docker image…')
  const stopBuildTimer = output.time()

  try {
    const { buildId, err } = await docker.build(config)

    doneWithBuild()

    if (buildId) {
      output.success(
        `Build complete ${output.param(buildId)} ${stopBuildTimer()}`
      )
      return { buildId }
    } else if (err) {
      output.error('There was an issue building the docker image:')
      console.log(err.message || err)
      return { err }
    } else {
      output.error('There was an unknown issue building the docker image')
      return { err: 'Unknown' }
    }
  } catch (err) {
    doneWithBuild()
    output.error('There was an issue building the docker image:')
    console.log(err)
    return { err }
  }
}
