const chalk = require('chalk')

const output = require('./utils/output')
const { getConfig } = require('./utils/config')
const { listPods, listServices } = require('./utils/kubernetes')

module.exports = async function list(opts = {}) {
  const { show = {} } = opts
  const config = await getConfig()
  const clusterName = output.param(config.cluster)
  const rbacUser = output.param(config.user)
  const { name } = config

  output.info(
    `Listing ${output.param(
      name
    )} Kubernetes objects on ${clusterName} as ${rbacUser}\n`
  )

  try {
    if (show.pods) {
      const stopPodsTimer = output.time()
      const { stdout: podsOut, stderr: podsErr } = await listPods(config)

      output.info(`${chalk.bold('Pods')} ${stopPodsTimer()}\n`)

      if (podsErr) {
        output.info(podsErr + '\n')
      } else {
        console.log(podsOut + '\n')
      }
    }

    if (show.services) {
      const stopSvcTimer = output.time()
      const { stdout: svcOut, stderr: svcErr } = await listServices(config)

      output.info(`${chalk.bold('Services')} ${stopSvcTimer()}\n`)

      if (svcErr) {
        output.info(svcErr + '\n')
      } else {
        console.log(svcOut + '\n')
      }
    }
  } catch (err) {
    output.error(`There was an issue listing ${output.param(name)}`)
    console.log(err)
  }
}
