const ksuid = require('ksuid')
const merge = require('lodash.merge')

const { getConfigFile, getRepoConfigFile, getPath } = require('./fs')
const { getClusterInfo } = require('./kubernetes')

module.exports = {
  getConfig
}

async function getConfig(input = {}) {
  const { name, pathDir, rootDir } = getPath()
  const configFromFile = await getConfigFile(rootDir)
  const repoConfigFromFile = await getRepoConfigFile(rootDir)
  const { cluster, user } = await getClusterInfo()
  const envTag = process.env.FUNK_TAG
  const tag = envTag || ksuid.randomSync().string

  // TODO:
  // - use git commit sha, if the branch is clean
  // - check if there were changes since the last deploy

  return {
    name,
    pathDir,
    rootDir,
    shouldBuild: !envTag,
    ...merge(
      {
        prefixReadyURL: repoConfigFromFile.prefixReadyURL,
        options: repoConfigFromFile.options
      },
      configFromFile
    ),
    tag,
    ...input,
    cluster,
    user
  }
}
