const fs = require('fs-extra')

module.exports = {
  getPath,
  getRootDir,
  getConfigFile,
  getRepoConfigFile
}

async function getRepoConfigFile(dir) {
  try {
    const pathParts = dir.split('/')

    for (let index = pathParts.length - 1; index >= 0; index--) {
      const potentialPath = pathParts.slice(0, index).join('/') + '/funk.json'

      try {
        const { isFile } = await fs.stat(potentialPath)

        if (isFile) {
          const configFile = await fs.readFile(potentialPath)
          const repoConfig = JSON.parse(configFile)

          // Confirm that it's a repository config
          if (repoConfig.type === 'repository') {
            return repoConfig
          }
        }
      } catch (err) {
        // silence error from fs.stat
      }
    }

    return {}
  } catch (err) {
    // TODO: Handle error
    return {}
  }
}

async function getConfigFile(rootDir) {
  try {
    const configFile = await fs.readFile(rootDir + '/funk.json')

    return JSON.parse(configFile)
  } catch (err) {
    // TODO: Handle error
    return {}
  }
}

function getPath() {
  const rootDir = getRootDir()
  const pathParts = rootDir.split('/')
  const newPath = []

  const name = pathParts.pop()

  newPath.unshift(name)
  newPath.unshift(pathParts.pop())
  newPath.unshift(pathParts.pop())

  return {
    name,
    rootDir,
    pathDir: newPath.join('/')
  }
}

function getRootDir() {
  // TODO: upward lookup for nearest `funk.json` or `Dockerfile`
  return process.cwd()
}
